import React from 'react';
import PropTypes from 'prop-types';
import { Button, Toast } from 'antd-mobile';
import './style.scss';
import { getPositions } from '../../api/index';
import UserInfoContext from '../../context/userinfo-context';
import WxWrap from '../../HOC/wx';
import scanImg from '../../images/Equipment/scan.png';
import { filterEmoji } from '../../utils/index';

export class Bindequipment extends React.Component {
  static propTypes = {
    updateUserInfo: PropTypes.func,
    userinfo: PropTypes.object,
  };
  constructor(props) {
    super(props);
    this.state = {
      deviceCode: '',
    };
  }

  componentWillMount() {
    const { setTitle } = this.props;
    setTitle('输入设备编号');
  }
  changeHandle = e => {
    let value = e.target.value.trim();
    value = filterEmoji(value);
    this.setState({
      deviceCode: value,
    });
  };
  validate = () => {
    const { deviceCode } = this.state;
    if (deviceCode) {
      return true;
    } else {
      Toast.fail('请输入设备编号');
    }
  };
  bindEquipment = () => {
    if (this.validate()) {
      Toast.loading('', 20);
      const { history, userinfo, updateUserInfo } = this.props;
      const { deviceCode } = this.state;
      getPositions({
        deviceCode,
        token: userinfo.token,
      })
        .then(res => {
          Toast.hide();
          // console.log(res);
          const { barcode, ...data } = res.data;
          if (data.id) {
            updateUserInfo({ barcode, position: { ...data, isBind: true } });
          } else {
            updateUserInfo({ barcode, position: { ...data, isBind: false } });
          }
          history.push({
            pathname: '/Equipment/' + deviceCode,
          });
        })
        .catch(err => {
          Toast.fail(err.msg || '请求失败');
        });
    }
  };
  scanEquipment = () => {
    const { wxDone, wxConfigHandle } = this.props;
    console.log('wxDone', wxDone);

    if (wxDone) {
      this.scanHandle();
    } else {
      wxConfigHandle()
        .then(() => {
          console.log('in res');
          this.scanHandle();
        })
        .catch(() => {
          console.log('in error');
          Toast.fail('启用微信失败！');
        });
    }
  };
  scanHandle = () => {
    const { wxConfigHandle } = this.props;
    const wx = window.wx;
    wx.scanQRCode({
      needResult: 1, // 默认为0，扫描结果由微信处理，1则直接返回扫描结果，
      scanType: ['qrCode', 'barCode'], // 可以指定扫二维码还是一维码，默认二者都有
      success: res => {
        const result = res.resultStr; // 当needResult 为 1 时，扫码返回的结果
        this.setState({
          deviceCode: result,
        });
      },
      fail: err => {
        console.log(err);
        Toast.info(err.errMsg || '调用扫一扫失败！');
        wxConfigHandle();
      },
    });
  };
  render() {
    const { deviceCode } = this.state;
    return (
      <div className='appContent BindEquipment'>
        <div className='inputBox'>
          <div className='inputWrap'>
            <input
              className='br8 input'
              onChange={this.changeHandle}
              value={deviceCode}
              type='text'
              placeholder='请输入设备编号'
              maxLength='8'
            />
            <Button
              type='primary'
              className='scan'
              onClick={this.scanEquipment}>
              <div className='scanicon'>
                <img src={scanImg} alt='' />
              </div>
            </Button>
          </div>
          <Button type='primary' className='btn' onClick={this.bindEquipment}>
            确定
          </Button>
        </div>
      </div>
    );
  }
}

export default props => (
  <WxWrap
    render={state => (
      <UserInfoContext.Consumer>
        {({ updateUserInfo, userinfo }) => (
          <Bindequipment
            {...props}
            {...state}
            updateUserInfo={updateUserInfo}
            userinfo={userinfo}
          />
        )}
      </UserInfoContext.Consumer>
    )}
  />
);
