import React from 'react';
import PropTypes from 'prop-types';
import { Button, Toast } from 'antd-mobile';
import './style.scss';
import eqIcon from '../../images/Equipment/equip_number_icon@2x.png';
import rateIcon from '../../images/Rate/rate_detail_icon@2x.png';
import { fetchRate, activateRate } from '../../api/index';

export class Index extends React.Component {
  static propTypes = {
    name: PropTypes.string,
  };
  constructor(props) {
    super(props);
    this.state = {
      mode: null,
      type: 1,
      measure: '0',
      money: '0.00',
      startingDuration: '0',
      startingMoney: '0.00',
    };
  }

  componentWillMount() {
    const { setTitle } = this.props;
    const { deviceCode } = this.props.match.params;
    setTitle('费率激活');
    fetchRate(deviceCode)
      .then(res => {
        console.log(res);
        const {
          measure,
          money,
          startingDuration,
          startingMoney,
          mode,
          type,
        } = res.data;
        this.setState({
          measure,
          money: (money / 100).toFixed(2),
          startingDuration,
          startingMoney: (startingMoney / 100).toFixed(2),
          mode,
          type,
        });
      })
      .catch(err => {
        Toast.fail(err.msg || '费率请求失败');
      });
  }
  clickHandle = () => {
    Toast.loading('', 20);
    const { deviceCode } = this.props.match.params;
    activateRate({ deviceCode })
      .then(res => {
        console.log(res);
        Toast.success(res.msg);
      })
      .catch(err => {
        Toast.fail(err.msg || '费率请求失败');
      });
  };
  render() {
    const { deviceCode } = this.props.match.params;
    const { measure, money, startingDuration, startingMoney } = this.state;

    return (
      <div className='appContent RateActivity'>
        <div className='inputBox'>
          <i className='inputIcon'>
            <img src={eqIcon} alt='' />
          </i>
          <span className='ellipsis inputText'>
            设备编号：
            {deviceCode}
          </span>
        </div>
        <div className='inputBox'>
          <i className='inputIcon'>
            <img src={rateIcon} alt='' />
          </i>
          <span className='ellipsis inputText'>费率详情:</span>
        </div>
        <div className='rateBox'>
          <div className='rateArea'>
            <div className='rateTitle'>
              <span className='rateItem'>费率价格(元)</span>
              <span className='rateItem'>费率单位(s)</span>
            </div>
            <div className='line' />
            <div className='ratePrice'>
              <span className='rateItem'>{money}</span>
              <span className='rateItem'>{measure}</span>
            </div>
          </div>
          <div className='rateArea'>
            <div className='rateTitle'>
              <span className='rateItem'>起步费率价格(元)</span>
              <span className='rateItem'>起步费率单位(s)</span>
            </div>
            <div className='line' />
            <div className='ratePrice'>
              <span className='rateItem'>{startingMoney}</span>
              <span className='rateItem'>{startingDuration}</span>
            </div>
          </div>
        </div>
        <Button type='primary' className='btn' onClick={this.clickHandle}>
          激活费率
        </Button>
      </div>
    );
  }
}

export default Index;
